Enum CalibrationResult
#[non_exhaustive]pub enum CalibrationResult {
Ok,
DataCheckFailed,
}Available on crate feature
unstable only.Expand description
Result of the PHY calibration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ok
The calibration data was valid and was used for calibration.
DataCheckFailed
The calibration data checksum check failed, or the calibration data was outdated.