phy_calibration_data

Function phy_calibration_data 

pub fn phy_calibration_data(data: &mut [u8; 1904])
Available on crate feature unstable only.
Get calibration data.

Returns the last calibration result.

If last_calibration_result returns CalibrationResult::DataCheckFailed, consider persisting the new data.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.