pub fn last_calibration_result() -> Option<CalibrationResult>Available on crate feature
unstable only.Expand description
Get the last calibration result.
This can be used to know if any previously persisted calibration data is outdated/invalid and needs to get updated.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.