pub fn set_phy_calibration_data(data: &[u8; 1904])Available on crate feature
unstable only.Expand description
Set calibration data.
This will be used next time the phy gets initialized.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.